@@ -37,13 +37,13 @@ def test__csv_validator_spaces():
         assert result[i] == value
 
 def test__regexp_csv_validator_valid():
-    pattern_strings = ["test_.*", "foo\.bar", "^baz$"]
+    pattern_strings = ["test_.*", "foo\\.bar", "^baz$"]
     result = config._regexp_csv_validator(None, None, ",".join(pattern_strings))
     for i, regex in enumerate(result):
         assert isinstance(regex, re._pattern_type)
         assert regex.pattern == pattern_strings[i]
 
 def test__regexp_csv_validator_invalid():
-    pattern_strings = ["test_.*", "foo\.bar", "^baz)$"]
+    pattern_strings = ["test_.*", "foo\\.bar", "^baz)$"]
     with pytest.raises(sre_constants.error):
         config._regexp_csv_validator(None, None, ",".join(pattern_strings))
